package com.yijia.station.service;

import java.util.List;
import com.yijia.station.domain.StationPay;

/**
 * 油站支付设置Service接口
 * 
 * @author yijia
 * @date 2020-12-10
 */
public interface IStationPayService 
{
    /**
     * 查询油站支付设置
     * 
     * @param payId 油站支付设置ID
     * @return 油站支付设置
     */
    public StationPay selectStationPayById(Long payId);

    /**
     * 查询油站支付设置列表
     * 
     * @param stationPay 油站支付设置
     * @return 油站支付设置集合
     */
    public List<StationPay> selectStationPayList(StationPay stationPay);

    /**
     * 新增油站支付设置
     * 
     * @param stationPay 油站支付设置
     * @return 结果
     */
    public int insertStationPay(StationPay stationPay);

    /**
     * 修改油站支付设置
     * 
     * @param stationPay 油站支付设置
     * @return 结果
     */
    public int updateStationPay(StationPay stationPay);

    /**
     * 批量删除油站支付设置
     * 
     * @param payIds 需要删除的油站支付设置ID
     * @return 结果
     */
    public int deleteStationPayByIds(Long[] payIds);

    /**
     * 删除油站支付设置信息
     * 
     * @param payId 油站支付设置ID
     * @return 结果
     */
    public int deleteStationPayById(Long payId);

    /**
     * 查询支付设置信息
     * @param stationPay
     * @return
     */
    public StationPay selectStationPayOne(StationPay stationPay);
}
